==> custom-toolbox_24.5.02.tar.xz: BUILD/translations/custom-toolbox_fr_BE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Custom Toolbox</source>
        <translation>Boîte à outils personnalisée - Custom Toolbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>À propos ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Personnaliser le lanceur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Fermer l’application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Ceci est un lanceur personnalisé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Afficher cette fenêtre au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Open List File</source>
        <translation>Ouvrir le fichier liste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>List Files (*.list)</source>
        <translation>Liste des fichiers (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Selection Error</source>
        <translation>Erreur de sélection de fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Aucun fichier sélectionné. L’application va se fermer maintenant.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>File Open Error</source>
        <translation>Erreur d’ouverture du fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Impossible d’ouvrir le fichier. Voulez-vous réessayer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>File Not Found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The file %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Could not open file: </source>
        <translation>Impossible d’ouvrir le fichier: </translation>
    </message>
    <message>
        <source>Application will close.</source>
        <translation type="vanished">L’application se fermera.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>La boîte à outils personnalisée «&#xa0;Custom Toolbox&#xa0;» est un outil utilisé pour créer un lanceur personnalisé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Could not write file: %1</source>
        <translation>Impossible d’écrire le fichier: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>File Removal Error</source>
        <translation>Erreur de suppression de fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Could not remove file: %1</source>
        <translation>Impossible de supprimer le fichier: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Cette application peut être utilisée pour créer des lanceurs personnalisés: boîte de boutons ou icônes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Ne pas afficher la case à cocher «&#xa0;Afficher cette boîte de dialogue au démarrage&#xa0;»</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Chemin complet et nom du fichier .list que vous souhaitez charger pour configurer l’application</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur•rice normal•e pour utiliser ce programme.</translation>
    </message>
</context>
</TS>

==> custom-toolbox_24.6.tar.xz: BUILD/translations/custom-toolbox_fr_BE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>Custom Toolbox</source>
        <translation>Boîte à outils personnalisée - Custom Toolbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>À propos ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Personnaliser le lanceur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Éditer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Fermer l’application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Ceci est un lanceur personnalisé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Afficher cette fenêtre au démarrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Open List File</source>
        <translation>Ouvrir le fichier liste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>List Files (*.list)</source>
        <translation>Liste des fichiers (*.list)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>File Selection Error</source>
        <translation>Erreur de sélection de fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Aucun fichier sélectionné. L’application va se fermer maintenant.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>File Open Error</source>
        <translation>Erreur d’ouverture du fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Impossible d’ouvrir le fichier. Voulez-vous réessayer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>File Not Found</source>
        <translation>Fichier introuvable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The file %1 does not exist.</source>
        <translation>Le fichier %1 n’existe pas.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Could not open file: </source>
        <translation>Impossible d’ouvrir le fichier: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>About %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="567"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>La boîte à outils personnalisée «&#xa0;Custom Toolbox&#xa0;» est un outil utilisé pour créer un lanceur personnalisé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Could not write file: %1</source>
        <translation>Impossible d’écrire le fichier: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>File Removal Error</source>
        <translation>Erreur de suppression de fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Could not remove file: %1</source>
        <translation>Impossible de supprimer le fichier: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Cette application peut être utilisée pour créer des lanceurs personnalisés: boîte de boutons ou icônes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Ne pas afficher la case à cocher «&#xa0;Afficher cette boîte de dialogue au démarrage&#xa0;»</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Chemin complet et nom du fichier .list que vous souhaitez charger pour configurer l’application</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur•rice normal•e pour utiliser ce programme.</translation>
    </message>
</context>
</TS>
